0.1.0 (2020-07-26) ()
================

New Features
------------

-Added ability to contact Astrometry.net for plate solving.

Other Changes and Additions
---------------------------

-Changed name from Draco to Dorado in preparation for publishing.

-Added documentation.

-Setup version control and packaging logic.

Bug Fixes
---------

-Fixed setup errors which used local versioning for PyPi which would result in an error on twine submit.

0.1.0 (2020-07-26)
================

- Initial release.
